@@ -15,7 +15,6 @@ use ast_grep_core::Pattern;
 use ast_grep_core::{AstGrep, Matcher, StrDoc};
 use ast_grep_language::Language;
 
-use std::env;
 use std::fs::read_to_string;
 use std::io::stdout;
 use std::io::Write;
@@ -74,27 +73,51 @@ pub fn prompt(prompt_text: &str, letters: &str, default: Option<char>) -> Result
   }
 }
 
+/// A trait to abstract how ast-grep discovers work Items.
+///
+/// It follows multiple-producer-single-consumer pattern.
+/// ast-grep will produce items in one or more separate thread(s) and
+/// `consumer_items` in the main thread, blocking the function return.
+/// Worker at the moment has two main flavors:
+/// * PathWorker: discovers files on the file system, based on ignore
+/// * StdInWorker: parse text content from standard input stream
+pub trait Worker: Sync {
+  /// The item to send between producer/consumer threads.
+  /// It is usually parsed tree-sitter Root with optional data.
+  type Item: Send;
+  /// `consume_items` will run in a separate single thread.
+  /// printing matches or error reporting can happen here.
+  fn consume_items(&self, items: Items<Self::Item>) -> Result<()>;
+}
+
 /// A trait to abstract how ast-grep discovers, parses and processes files.
 ///
 /// It follows multiple-producer-single-consumer pattern.
 /// ast-grep discovers files in parallel by `build_walk`.
 /// Then every file is parsed and filtered in `produce_item`.
 /// Finally, `produce_item` will send `Item` to the consumer thread.
-pub trait Worker: Sync {
-  /// The item to send between producer/consumer threads.
-  /// It is usually parsed tree-sitter Root with optional data.
-  type Item: Send;
+pub trait PathWorker: Worker {
   /// WalkParallel will determine what files will be processed.
   fn build_walk(&self) -> WalkParallel;
   /// Parse and find_match can be done in `produce_item`.
   fn produce_item(&self, path: &Path) -> Option<Self::Item>;
-  /// `consume_items` will run in a separate single thread.
-  /// printing matches or error reporting can happen here.
-  fn consume_items(&self, items: Items<Self::Item>) -> Result<()>;
+
+  fn run_path(&self) -> Result<()> {
+    run_worker(self)
+  }
 }
 
 pub trait StdInWorker: Worker {
   fn parse_stdin(&self, src: String) -> Option<Self::Item>;
+
+  fn run_std_in(&self) -> Result<()> {
+    let source = std::io::read_to_string(std::io::stdin())?;
+    if let Some(item) = self.parse_stdin(source) {
+      self.consume_items(Items::once(item)?)
+    } else {
+      Ok(())
+    }
+  }
 }
 
 pub struct Items<T>(mpsc::Receiver<T>);
@@ -109,7 +132,7 @@ impl<T> Iterator for Items<T> {
   }
 }
 impl<T> Items<T> {
-  pub fn once(t: T) -> Result<Self> {
+  fn once(t: T) -> Result<Self> {
     let (tx, rx) = mpsc::channel();
     // use write to avoid send/sync trait bound
     match tx.send(t) {
@@ -131,16 +154,7 @@ fn filter_result(result: Result<DirEntry, ignore::Error>) -> Option<PathBuf> {
   entry.file_type()?.is_file().then(|| entry.into_path())
 }
 
-pub fn run_std_in<MW: StdInWorker>(worker: MW) -> Result<()> {
-  let source = std::io::read_to_string(std::io::stdin())?;
-  if let Some(item) = worker.parse_stdin(source) {
-    worker.consume_items(Items::once(item)?)
-  } else {
-    Ok(())
-  }
-}
-
-pub fn run_worker<MW: Worker>(worker: MW) -> Result<()> {
+fn run_worker<W: PathWorker + ?Sized>(worker: &W) -> Result<()> {
   let producer = |path: PathBuf| worker.produce_item(&path);
   let (tx, rx) = mpsc::channel();
   let walker = worker.build_walk();
@@ -227,13 +241,6 @@ pub struct MatchUnit<M: Matcher<SgLang>> {
   pub matcher: M,
 }
 
-#[inline]
-fn is_from_stdin() -> bool {
-  // disable stdin if tty env presents or is_atty == true
-  // env is used for testing purpose only
-  env::var_os("AST_GREP_NO_STDIN").is_none() && !atty::is(atty::Stream::Stdin)
-}
-
 /// input related options
 #[derive(Args)]
 pub struct InputArgs {
@@ -250,16 +257,11 @@ pub struct InputArgs {
   /// Enable search code from StdIn.
   ///
   /// Use this if you need to take code stream from standard input.
-  /// If the environment variable `AST_GREP_NO_STDIN` exist, ast-grep will disable StdIn mode.
   #[clap(long)]
   pub stdin: bool,
 }
 
 impl InputArgs {
-  pub fn is_stdin(&self) -> bool {
-    self.stdin && is_from_stdin()
-  }
-
   pub fn walk(&self) -> WalkParallel {
     let threads = num_cpus::get().min(12);
     NoIgnore::disregard(&self.no_ignore)
