@@ -278,9 +278,12 @@ pub fn deserialize_rule<L: Language>(
   let mut rules = Vec::with_capacity(1);
   use Rule as R;
   let categorized = serialized.categorized();
+  // ATTENTION, relational_rule should always come at last
+  // after target node is decided by atomic/composite rule
   deserialze_atomic_rule(categorized.atomic, &mut rules, env)?;
-  deserialize_relational_rule(categorized.relational, &mut rules, env)?;
   deserialze_composite_rule(categorized.composite, &mut rules, env)?;
+  deserialize_relational_rule(categorized.relational, &mut rules, env)?;
+
   if rules.is_empty() {
     Err(RuleSerializeError::MissPositiveMatcher)
   } else if rules.len() == 1 {
@@ -369,6 +372,7 @@ fn deserialze_atomic_rule<L: Language>(
 mod test {
   use super::*;
   use crate::from_str;
+  use crate::test::TypeScript;
   use PatternStyle::*;
 
   #[test]
@@ -462,4 +466,38 @@ follows:
     assert!(follows.rule.pattern.is_present());
     assert!(follows.rule.pattern.is_present());
   }
+
+  #[test]
+  fn test_deserialize_rule() {
+    let src = r"
+pattern: class A {}
+kind: class_declaration
+";
+    let rule: SerializableRule = from_str(src).expect("cannot parse rule");
+    let env = DeserializeEnv::new(TypeScript::Tsx);
+    let rule = deserialize_rule(rule, &env).expect("should deserialize");
+    assert!(rule.is_composite());
+    let root = TypeScript::Tsx.ast_grep("class A {}");
+    assert!(root.root().find(rule).is_some());
+  }
+
+  #[test]
+  fn test_deserialize_order() {
+    let src = r"
+pattern: class A {}
+inside:
+  kind: class
+";
+    let rule: SerializableRule = from_str(src).expect("cannot parse rule");
+    let env = DeserializeEnv::new(TypeScript::Tsx);
+    let rule = deserialize_rule(rule, &env).expect("should deserialize");
+    assert!(rule.is_composite());
+    let Rule::All(rules) = rule else {
+      panic!("should parsed as all");
+    };
+    // relational_rule should be the last
+    let rules = rules.inner();
+    assert!(rules[0].is_atomic());
+    assert!(rules[1].is_relational());
+  }
 }
